// yfs wire protocol

#ifndef yfs_protocol_h
#define yfs_protocol_h

#include "rpc.h"

class yfs_protocol {
 public:
  typedef unsigned long long inum;
  enum xxstatus { OK, RPCERR, NOENT, IOERR, FBIG };
  typedef int status;
  enum rpc_numbers {
    getfile = 0x5001,
    getdir,
    lookup,
    readdir,
    readfile,
    writefile,
    create,
    setsize,
    unlink
  };

  struct fileinfo {
    unsigned long long size;
    unsigned long atime;
    unsigned long mtime;
    unsigned long ctime;
  };
  struct dirinfo {
    unsigned long atime;
    unsigned long mtime;
    unsigned long ctime;
  };
  struct dirent {
    std::string name;
    unsigned long long inum;
  };
};

inline unmarshall &
operator>>(unmarshall &u, yfs_protocol::dirent &e)
{
  u >> e.name;
  u >> e.inum;
  return u;
}

inline marshall &
operator<<(marshall &m, yfs_protocol::dirent e)
{
  m << e.name;
  m << e.inum;
  return m;
}

inline unmarshall &
operator>>(unmarshall &u, yfs_protocol::fileinfo &e)
{
  u >> e.size;
  u >> e.atime;
  u >> e.mtime;
  u >> e.ctime;
  return u;
}

inline marshall &
operator<<(marshall &m, yfs_protocol::fileinfo e)
{
  m << e.size;
  m << e.atime;
  m << e.mtime;
  m << e.ctime;
  return m;
}

inline unmarshall &
operator>>(unmarshall &u, yfs_protocol::dirinfo &e)
{
  u >> e.atime;
  u >> e.mtime;
  u >> e.ctime;
  return u;
}

inline marshall &
operator<<(marshall &m, yfs_protocol::dirinfo e)
{
  m << e.atime;
  m << e.mtime;
  m << e.ctime;
  return m;
}

#endif 
