// yfs remove server

#include "yfs_server.h"
#include "extent_client.h"
#include <sstream>
#include <iostream>
#include <stdio.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>


yfs_server::yfs_server(struct sockaddr_in extent_dst, 
		       struct sockaddr_in lock_dst,
		       int rlock_port)
{
  ec = new extent_client(extent_dst);
}

yfs_protocol::inum
yfs_server::inum(std::string n)
{
  std::istringstream ist(n);
  unsigned long long finum;
  ist >> finum;
  return finum;
}

std::string
yfs_server::filename(yfs_protocol::inum inum)
{
  std::ostringstream ost;
  ost << inum;
  return ost.str();
}

bool
yfs_server::isfile(yfs_protocol::inum inum)
{
  if(inum & 0x80000000)
    return true;
  return false;
}

bool
yfs_server::isdir(yfs_protocol::inum inum)
{
  return ! isfile(inum);
}

int
yfs_server::getfile(yfs_protocol::inum inum, yfs_protocol::fileinfo &fin)
{
  int r = yfs_protocol::OK;
  std::string f = filename(inum);


  printf("getfile %016llx\n", inum);
  extent_protocol::attr a;
  if (ec->getattr(inum, a) != extent_protocol::OK) {
    r = yfs_protocol::IOERR;
    goto release;
  }

  fin.atime = a.atime;
  fin.mtime = a.mtime;
  fin.ctime = a.ctime;
  fin.size = a.size;
  printf("getfile %016llx -> sz %llu\n", inum, fin.size);

 release:

  return r;
}

int
yfs_server::getdir(yfs_protocol::inum inum, yfs_protocol::dirinfo &din)
{
  int r = yfs_protocol::OK;
  std::string d = filename(inum);


  printf("getdir %016llx\n", inum);
  extent_protocol::attr a;
  if (ec->getattr(inum, a) != extent_protocol::OK) {
    r = yfs_protocol::IOERR;
    goto release;
  }
  din.atime = a.atime;
  din.mtime = a.mtime;
  din.ctime = a.ctime;

 release:
  return r;
}



